@@ -81,37 +81,6 @@ impl Command {
                 .next()
         })
     }
-
-    /*
-    pub fn format(&self, fmt: &str) -> String {
-        let duration = self.duration_string();
-        let cur_dir = match &self.working_dir {
-            Some(dir) => format!("{}", dir.display()),
-            None => "".to_string(),
-        };
-        if fmt == "%F" {
-            if cur_dir.len() > 0 {
-                format!(
-                    "{} {} {} ({},{})",
-                    &self.status(),
-                    &self.name().yellow().bold(),
-                    &self.args.join(" "),
-                    cur_dir.white().bold(),
-                    duration.white().bold(),
-                )
-            } else {
-                format!(
-                    "{} {} {} ({})",
-                    &self.status(),
-                    &self.name().yellow().bold(),
-                    &self.args.join(" "),
-                    duration.white().bold(),
-                )
-            }
-        } else {
-            format!("{}", self)
-        }
-    }*/
 }
 
 // immutable methods
@@ -364,9 +333,9 @@ impl Display for Command {
                     "{} {} {} ({},{})",
                     &self.status(),
                     &self.name().yellow().bold(),
-                    &self.args.join(" "),
-                    cur_dir.white().bold(),
-                    duration.white().bold()
+                    &self.args.join(" ").white().bold(),
+                    cur_dir,
+                    duration
                 )
             }
             None => write!(
@@ -374,8 +343,8 @@ impl Display for Command {
                 "{} {} {} ({})",
                 &self.status(),
                 &self.name().yellow().bold(),
-                &self.args.join(" "),
-                duration.white().bold(),
+                &self.args.join(" ").white().bold(),
+                duration,
             ),
         }
     }
